- brew install brew-cask-completion
    - brew cask search chrome
    - brew cask install google-chrome
    
- https://mp.weixin.qq.com/s/7d2WHcW9LmrdI3lJu2SQzg
```bash
chsh -s /bin/zshsh -c "$(curl -fsSL https://raw.github.com/robbyrussell/oh-my-zsh/master/tools/install.sh)"
```